@@ -17,8 +17,11 @@ from leetcode_export.utils import VALID_PROGRAMMING_LANGUAGES
 def parse_args():
     parser = argparse.ArgumentParser(
         description="Export LeetCode submissions",
-        formatter_class=argparse.RawTextHelpFormatter,
+        formatter_class=lambda prog: argparse.RawTextHelpFormatter(
+            "leetcode-export", width=80
+        ),
     )
+
     parser.add_argument("--cookies", type=str, help="set LeetCode cookies")
     parser.add_argument("--folder", type=str, default=".", help="set output folder")
     parser.add_argument(
@@ -27,6 +30,12 @@ def parse_args():
         default="${question_id}-${title_slug}",
         help="problem folder name format",
     )
+    parser.add_argument(
+        "--no-problem-statement",
+        dest="no_problem_statement",
+        action="store_true",
+        help="do not save problem statement",
+    )
     parser.add_argument(
         "--problem-statement-filename",
         type=str,
@@ -52,13 +61,23 @@ def parse_args():
         action="store_true",
         help="save accepted submissions only",
     )
+    parser.add_argument(
+        "--only-last-submission",
+        dest="only_last_submission",
+        action="store_true",
+        help="only save the last submission for each programming language",
+    )
     parser.add_argument(
         "--language",
         dest="language_unprocessed",
         type=str,
-        help="only save submissions for the specified programming languages (eg. '--language=python,python3,cpp,java,golang')\n"
-        + "supported languages: 'python', 'python3', 'c', 'cpp', 'csharp', 'java', 'kotlin', 'mysql', 'mssql', 'oraclesql',\n"
-        + "                     'javascript', 'html', 'php', 'golang', 'scala', 'pythonml', 'rust', 'ruby', 'bash', 'swift'",
+        help="save submissions for specified programming languages.\n"
+        "syntax: --language=<lang1>,<lang2>,...\n"
+        "languages: python, python3, c, cpp, csharp, java,\n"
+        "           kotlin, mysql, mssql, oraclesql, javascript,\n"
+        "           html, php, golang, scala, pythonml,\n"
+        "           rust, ruby, bash, swift\n"
+        "example: --language=python,cpp,java",
     )
     parser.add_argument(
         "-v",
@@ -97,23 +116,31 @@ def parse_args():
     return args
 
 
-def main():
-    args = parse_args()
+def configure_logging(args):
+    logging_file_handler = logging.FileHandler("debug.log", encoding="UTF8")
+    logging_file_handler.setLevel(logging.DEBUG)
 
-    # Set logging level based on program arguments
-    level = logging.WARNING
+    logging_stream_handler = logging.StreamHandler()
+
+    # Set stream logging level based on program arguments
+    logging_stream_handler.setLevel(logging.WARNING)
     if args.verbose:
-        level = logging.INFO
+        logging_stream_handler.setLevel(logging.INFO)
     if args.extra_verbose:
-        level = logging.DEBUG
+        logging_stream_handler.setLevel(logging.DEBUG)
 
     logging.basicConfig(
-        level=level,
+        level=logging.DEBUG,
         format="%(asctime)s [%(levelname)s] %(filename)s:%(lineno)d - %(message)s",
-        handlers=[logging.FileHandler("debug.log"), logging.StreamHandler()],
+        handlers=[logging_file_handler, logging_stream_handler],
     )
 
-    logging.info(args)
+
+def main():
+    args = parse_args()
+    configure_logging(args)
+
+    logging.info("leetcode-export run with arguments: " + str(args))
 
     problem_folder_name_template = Template(args.problem_folder_name)
     problem_statement_filename_template = Template(args.problem_statement_filename)
@@ -134,18 +161,54 @@ def main():
 
     # Create output folder if it doesn't already exist
     if not os.path.exists(args.folder):
+        logging.info("Output folder not found, creating it")
         os.mkdir(args.folder)
     os.chdir(args.folder)
 
     title_slug_to_problem_folder_name: dict[str, str] = dict()
+    title_slug_to_exported_languages: dict[str, set[str]] = dict()
+
+    last_submission_timestamp: Optional[int] = None
+
+    print("Exporting LeetCode submissions...")
 
     for submission in leetcode.get_submissions():
+        if (
+            last_submission_timestamp is not None
+            and submission.timestamp > last_submission_timestamp
+        ):
+            logging.warning(
+                "Submissions are not in reverse chronological order, --only-last-submission flag might not work as expected if used. Please report this issue on GitHub attaching the debug.log file: https://github.com/NeverMendel/leetcode-export/issues"
+            )
+        last_submission_timestamp = submission.timestamp
+
         if args.only_accepted and submission.status_display != "Accepted":
+            logging.info(
+                f"Skipping {submission.title_slug} {submission.date_formatted} because its status is '{submission.status_display}'"
+            )
             continue
 
         if args.language and submission.lang not in args.language:
+            logging.info(
+                f"Skipping {submission.title_slug} {submission.date_formatted} because its programming language is {submission.lang}"
+            )
             continue
 
+        if submission.title_slug not in title_slug_to_exported_languages:
+            title_slug_to_exported_languages[submission.title_slug] = set()
+
+        if (
+            args.only_last_submission
+            and submission.title_slug in title_slug_to_exported_languages
+            and submission.lang
+            in title_slug_to_exported_languages[submission.title_slug]
+        ):
+            logging.info(
+                f"Skipping {submission.title_slug} {submission.date_formatted} in {submission.lang} because a more recent submission has already been exported"
+            )
+            continue
+        title_slug_to_exported_languages[submission.title_slug].add(submission.lang)
+
         if submission.title_slug not in title_slug_to_problem_folder_name:
             problem_statement = leetcode.get_problem_statement(submission.title_slug)
             problem_folder_name = problem_folder_name_template.substitute(
@@ -161,7 +224,9 @@ def main():
             problem_statement_filename = problem_statement_filename_template.substitute(
                 **problem_statement.__dict__
             )
-            if not os.path.exists(problem_statement_filename):
+            if not args.no_problem_statement and not os.path.exists(
+                problem_statement_filename
+            ):
                 with open(problem_statement_filename, "w+") as problem_statement_file:
                     problem_statement_file.write(
                         problem_statement_template.substitute(
